@@ -28,7 +28,7 @@ psutil_boot_time(PyObject *self, PyObject *args) {
     UTXENT_MUTEX_UNLOCK();
     if (fabs(boot_time) < 0.000001) {
         /* could not find BOOT_TIME in getutxent loop */
-        PyErr_SetString(PyExc_RuntimeError, "can't determine boot time");
+        psutil_runtime_error("can't determine boot time");
         return NULL;
     }
     return Py_BuildValue("f", boot_time);
